@@ -53,7 +53,9 @@ main() {
 
       fwrite ( &block_buffer, 1, 1, stdout);
   }
-  mcrypt_generic_end(td);
+  mcrypt_generic_deinit(td);
+
+  mcrypt_module_close(td);
 
   return 0;
 
