@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt.c,v 1.16 2001/12/15 11:27:34 nmav Exp $ */
+/* $Id: mcrypt.c,v 1.17 2002/01/31 01:06:34 nmav Exp $ */
 
 /* Changed by Steve Underwood 1999/12/10 to allow an arbitrary number of 
  * streams of encryption. Currently the resulting code is probably not
@@ -252,8 +252,7 @@ const char* mcrypt_strerror(int err)
 }
 
 WIN32DLL_DEFINE
-int mcrypt_free(void *ptr)
+void mcrypt_free(void *ptr)
 {
 	free(ptr);
-	return 0;
 }
