@@ -16,7 +16,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: cast-256.c,v 1.7 2001/05/16 17:54:25 nmav Exp $ */
+/* $Id: cast-256.c,v 1.10 2001/09/09 09:52:54 nmav Exp $ */
 
 /* modified for mcrypt */
 
@@ -64,8 +64,9 @@ Mean:          674 cycles =    38.0 mbits/sec
 
 */
 
-#include "../../lib/libdefs.h"
-#include "../../lib/mcrypt_modules.h"
+#include <libdefs.h>
+
+#include <mcrypt_modules.h>
 #include "cast-256.h"
 
 #ifdef USE_LTDL
@@ -497,22 +498,17 @@ WIN32DLL_DEFINE int _mcrypt_get_key_size()
 	return 32;
 }
 
-WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+static const int key_sizes[] = { 16, 24, 32 };
+WIN32DLL_DEFINE const int *_mcrypt_get_supported_key_sizes(int *len)
 {
-	int *size = malloc(3 * sizeof(int));
-	size[0] = 16;
-	size[1] = 24;
-	size[2] = 32;
-	*len = 3;
-	return size;
+	*len = sizeof(key_sizes)/sizeof(int);
+	return key_sizes;
+
 }
 
-WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+WIN32DLL_DEFINE const char *_mcrypt_get_algorithms_name()
 {
-	char *x;
-	x = malloc(10);
-	strcpy(x, "CAST-256");
-	return x;
+return "CAST-256";
 }
 
 #define CIPHER "5db4dd765f1d3835615a14afcb5dc2f5"
@@ -574,5 +570,5 @@ WIN32DLL_DEFINE int _mcrypt_self_test()
 
 WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
 {
-	return 19991129;
+	return 20010801;
 }
